<?php
namespace Teknisa\CADFIS\Services;

use Doctrine\DBAL\Connection;
use Teknisa\Libs\Util\Environment;

class GeneralService
{
    public function __construct(Connection $connection, Environment $environment)
    {
        $this->connection = $connection;
        $this->environment = $environment;
    }
    
    public function verifyFornecedorExists($row)
    {
        $query = "SELECT CDFORNECED 
                    FROM FORNECEDOR 
                   WHERE CDFORNECED = :P_CDFORNECED
                     AND NRORG = :P_NRORG";
        $params = array(
            'P_CDFORNECED' => $row['CDFORNECED'],
            'P_NRORG'   => $this->environment->getNrorg(),
        );

        $stmt = $this->connection->prepare($query);
        $stmt->execute($params);
        
        return $stmt->fetch();
    }
    
    public function verifyCdProdutoExists($row)
    {
        $query = "SELECT CDPRODUTO 
                    FROM PRODUTO 
                   WHERE CDARVPROD = :P_CDARVPROD 
                     AND NRORG = :P_NRORG";
        $params = array(
            'P_CDARVPROD' => $row['CDARVPROD'],
            'P_NRORG'     => $this->environment->getNrorg(),
        );

        $stmt = $this->connection->prepare($query);
        $stmt->execute($params);
        
        return $stmt->fetch();
    }
    
    public function verifyUnidadeExists($row)
    {
        $query = "SELECT SGUNIDADE 
                    FROM UNIDMEDIDA 
                   WHERE SGUNIDADE = :P_SGUNIDADE
                     AND NRORG = :P_NRORG";
        $params = array(
            'P_SGUNIDADE' => $row['SGUNIDADE'],
            'P_NRORG'     => $this->environment->getNrorg(),
        );

        $stmt = $this->connection->prepare($query);
        $stmt->execute($params);
        
        return $stmt->fetch();
    }
    
    public function verifyMarcaExists($row)
    {
        $query = "SELECT CDMARCA 
                    FROM MARCA 
                   WHERE CDMARCA = :P_CDMARCA
                     AND NRORG = :P_NRORG";
        $params = array(
            'P_CDMARCA' => $row['CDMARCA'],
            'P_NRORG'   => $this->environment->getNrorg(),
        );

        $stmt = $this->connection->prepare($query);
        $stmt->execute($params);
        
        return $stmt->fetch();
    }
    
    public function verifyCdOperadorExists($row, $columnName)
    {
        $query = "SELECT CDOPERADOR 
                    FROM OPERADOR
                   WHERE CDOPERADOR = :P_CDOPERADOR 
                     AND NRORG = :P_NRORG";
        $params = array(
            'P_CDOPERADOR'     => $row[$columnName],
            'P_NRORG'       => $this->environment->getNrorg(),
        );

        $stmt = $this->connection->prepare($query);
        $stmt->execute($params);
        
        return $stmt->fetch();
    }
    
    public function verifyCdRegiaoExists($row)
    {
        $query = "SELECT CDREGIAO 
                    FROM REGIAO
                   WHERE CDREGIAO = :P_CDREGIAO 
                     AND NRORG = :P_NRORG";
        $params = array(
            'P_CDREGIAO'     => $row['CDREGIAO'],
            'P_NRORG'       => $this->environment->getNrorg(),
        );

        $stmt = $this->connection->prepare($query);
        $stmt->execute($params);
        
        return $stmt->fetch();
    }
    
    public function verifyCdPaisExists($row, $columnName = 'CDPAIS')
    {
        $query = "SELECT CDPAIS
                    FROM PAIS
                   WHERE CDPAIS = :P_CDPAIS
                     AND NRORG = :P_NRORG";
        $params = array(
            'P_CDPAIS'     => $row[$columnName],
            'P_NRORG'       => $this->environment->getNrorg(),
        );

        $stmt = $this->connection->prepare($query);
        $stmt->execute($params);
        
        return $stmt->fetch();
    }
    
    public function verifySgEstadoExists($row, $columnNameCdPais = 'CDPAIS', $columnNameSgEstado = 'SGESTADO')
    {
        $query = "SELECT SGESTADO
                    FROM ESTADO
                   WHERE CDPAIS = :P_CDPAIS
                     AND SGESTADO = :P_SGESTADO
                     AND NRORG = :P_NRORG";
        $params = array(
            'P_CDPAIS'     => $row[$columnNameCdPais],
            'P_SGESTADO'     => $row[$columnNameSgEstado],
            'P_NRORG'       => $this->environment->getNrorg(),
        );

        $stmt = $this->connection->prepare($query);
        $stmt->execute($params);
        
        return $stmt->fetch();
    }
    
    public function verifyCdMunicipioExists($row, $columnNameCdPais = 'CDPAIS', $columnNameSgEstado = 'SGESTADO', $columnNameCdMunicipio = 'CDMUNICIPIO')
    {
        $query = "SELECT CDMUNICIPIO
                    FROM MUNICIPIO
                   WHERE CDPAIS = :P_CDPAIS
                     AND SGESTADO = :P_SGESTADO
                     AND CDMUNICIPIO = :P_CDMUNICIPIO
                     AND NRORG = :P_NRORG";
        $params = array(
            'P_CDPAIS'     => $row[$columnNameCdPais],
            'P_SGESTADO'     => $row[$columnNameSgEstado],
            'P_CDMUNICIPIO' => $row[$columnNameCdMunicipio],
            'P_NRORG'       => $this->environment->getNrorg(),
        );

        $stmt = $this->connection->prepare($query);
        $stmt->execute($params);
        
        return $stmt->fetch();
    }
}